@@ -18,12 +18,12 @@ import tim.prune.function.DiskCacheConfig;
 import tim.prune.function.DownloadOsmFunction;
 import tim.prune.function.DuplicatePoint;
 import tim.prune.function.FindWaypoint;
-import tim.prune.function.FullRangeDetails;
+import tim.prune.function.ProjectPoint;
+import tim.prune.function.ShowFullDetails;
 import tim.prune.function.GetWikipediaFunction;
 import tim.prune.function.HelpScreen;
 import tim.prune.function.IgnoreExifThumb;
 import tim.prune.function.InterpolateFunction;
-import tim.prune.function.PasteCoordinates;
 import tim.prune.function.PhotoPopupFunction;
 import tim.prune.function.PlayAudioFunction;
 import tim.prune.function.RearrangePhotosFunction;
@@ -50,8 +50,6 @@ import tim.prune.function.distance.DistanceFunction;
 import tim.prune.function.edit.PointNameEditor;
 import tim.prune.function.estimate.EstimateTime;
 import tim.prune.function.estimate.LearnParameters;
-import tim.prune.function.gpsies.GetGpsiesFunction;
-import tim.prune.function.gpsies.UploadGpsiesFunction;
 import tim.prune.function.settings.SaveConfig;
 import tim.prune.function.settings.SetAltitudeTolerance;
 import tim.prune.function.settings.SetColours;
@@ -61,7 +59,6 @@ import tim.prune.function.settings.SetMapBgFunction;
 import tim.prune.function.settings.SetPathsFunction;
 import tim.prune.function.sew.SewTrackSegmentsFunction;
 import tim.prune.function.sew.SplitSegmentsFunction;
-import tim.prune.function.srtm.DownloadSrtmFunction;
 import tim.prune.function.srtm.LookupSrtmFunction;
 import tim.prune.function.weather.GetWeatherForecastFunction;
 import tim.prune.load.AudioLoader;
@@ -88,6 +85,7 @@ public abstract class FunctionLibrary
 	public static GenericFunction FUNCTION_IMPORTBABEL = null;
 	public static GenericFunction FUNCTION_SAVECONFIG  = null;
 	public static GenericFunction FUNCTION_EDIT_WAYPOINT_NAME = null;
+	public static GenericFunction FUNCTION_PROJECT_POINT = null;
 	public static GenericFunction FUNCTION_REARRANGE_WAYPOINTS = null;
 	public static GenericFunction FUNCTION_SELECT_SEGMENT = null;
 	public static GenericFunction FUNCTION_SPLIT_SEGMENTS = null;
@@ -103,7 +101,6 @@ public abstract class FunctionLibrary
 	public static GenericFunction FUNCTION_DELETE_BY_DATE = null;
 	public static SingleNumericParameterFunction FUNCTION_INTERPOLATE = null;
 	public static GenericFunction FUNCTION_LOOKUP_SRTM = null;
-	public static GenericFunction FUNCTION_DOWNLOAD_SRTM = null;
 	public static GenericFunction FUNCTION_NEARBY_WIKIPEDIA = null;
 	public static GenericFunction FUNCTION_SEARCH_WIKIPEDIA = null;
 	public static GenericFunction FUNCTION_SEARCH_OSMPOIS = null;
@@ -112,7 +109,6 @@ public abstract class FunctionLibrary
 	public static GenericFunction FUNCTION_ADD_ALTITUDE_OFFSET  = null;
 	public static GenericFunction FUNCTION_CONVERT_NAMES_TO_TIMES  = null;
 	public static GenericFunction FUNCTION_DELETE_FIELD_VALUES  = null;
-	public static GenericFunction FUNCTION_PASTE_COORDINATES = null;
 	public static GenericFunction FUNCTION_FIND_WAYPOINT = null;
 	public static GenericFunction FUNCTION_DUPLICATE_POINT = null;
 	public static GenericFunction FUNCTION_CONNECT_TO_POINT = null;
@@ -127,12 +123,10 @@ public abstract class FunctionLibrary
 	public static GenericFunction FUNCTION_CHARTS = null;
 	public static GenericFunction FUNCTION_3D     = null;
 	public static GenericFunction FUNCTION_DISTANCES  = null;
-	public static GenericFunction FUNCTION_FULL_RANGE_DETAILS = null;
+	public static GenericFunction FUNCTION_FULL_DETAILS = null;
 	public static GenericFunction FUNCTION_AUTOPLAY_TRACK = null;
 	public static GenericFunction FUNCTION_ESTIMATE_TIME = null;
 	public static GenericFunction FUNCTION_LEARN_ESTIMATION_PARAMS = null;
-	public static GenericFunction FUNCTION_GET_GPSIES = null;
-	public static GenericFunction FUNCTION_UPLOAD_GPSIES = null;
 	public static GenericFunction FUNCTION_GET_WEATHER_FORECAST = null;
 	public static GenericFunction FUNCTION_LOAD_AUDIO = null;
 	public static GenericFunction FUNCTION_REMOVE_AUDIO = null;
@@ -168,6 +162,7 @@ public abstract class FunctionLibrary
 		FUNCTION_IMPORTBABEL = new BabelLoadFromFile(inApp);
 		FUNCTION_SAVECONFIG = new SaveConfig(inApp);
 		FUNCTION_EDIT_WAYPOINT_NAME = new PointNameEditor(inApp);
+		FUNCTION_PROJECT_POINT = new ProjectPoint(inApp);
 		FUNCTION_REARRANGE_WAYPOINTS = new RearrangeWaypointsFunction(inApp);
 		FUNCTION_SELECT_SEGMENT = new SelectSegmentFunction(inApp);
 		FUNCTION_SPLIT_SEGMENTS = new SplitSegmentsFunction(inApp);
@@ -183,7 +178,6 @@ public abstract class FunctionLibrary
 		FUNCTION_DELETE_BY_DATE = new DeleteByDateFunction(inApp);
 		FUNCTION_INTERPOLATE = new InterpolateFunction(inApp);
 		FUNCTION_LOOKUP_SRTM = new LookupSrtmFunction(inApp);
-		FUNCTION_DOWNLOAD_SRTM = new DownloadSrtmFunction(inApp);
 		FUNCTION_NEARBY_WIKIPEDIA = new GetWikipediaFunction(inApp);
 		FUNCTION_SEARCH_WIKIPEDIA = new SearchWikipediaNames(inApp);
 		FUNCTION_SEARCH_OSMPOIS = new SearchOsmPoisFunction(inApp);
@@ -192,7 +186,6 @@ public abstract class FunctionLibrary
 		FUNCTION_ADD_ALTITUDE_OFFSET = new AddAltitudeOffset(inApp);
 		FUNCTION_CONVERT_NAMES_TO_TIMES = new ConvertNamesToTimes(inApp);
 		FUNCTION_DELETE_FIELD_VALUES = new DeleteFieldValues(inApp);
-		FUNCTION_PASTE_COORDINATES = new PasteCoordinates(inApp);
 		FUNCTION_FIND_WAYPOINT = new FindWaypoint(inApp);
 		FUNCTION_DUPLICATE_POINT = new DuplicatePoint(inApp);
 		FUNCTION_CONNECT_TO_POINT = new ConnectToPointFunction(inApp);
@@ -206,12 +199,10 @@ public abstract class FunctionLibrary
 		FUNCTION_CHARTS = new Charter(inApp);
 		FUNCTION_3D     = new ShowThreeDFunction(inApp);
 		FUNCTION_DISTANCES = new DistanceFunction(inApp);
-		FUNCTION_FULL_RANGE_DETAILS = new FullRangeDetails(inApp);
+		FUNCTION_FULL_DETAILS = new ShowFullDetails(inApp);
 		FUNCTION_AUTOPLAY_TRACK = new AutoplayFunction(inApp);
 		FUNCTION_ESTIMATE_TIME = new EstimateTime(inApp);
 		FUNCTION_LEARN_ESTIMATION_PARAMS = new LearnParameters(inApp);
-		FUNCTION_GET_GPSIES = new GetGpsiesFunction(inApp);
-		FUNCTION_UPLOAD_GPSIES = new UploadGpsiesFunction(inApp);
 		FUNCTION_GET_WEATHER_FORECAST = new GetWeatherForecastFunction(inApp);
 		FUNCTION_LOAD_AUDIO = new AudioLoader(inApp);
 		FUNCTION_REMOVE_AUDIO = new RemoveAudioFunction(inApp);
